import time
import threading
#
from mysqlog.parser import SlowQueryLog


class SlowQueryLogProducer(threading.Thread):

    def __init__(self, file, queue):
        threading.Thread.__init__(self, name=file.name)
        self.parser = SlowQueryLog(file)
        self.queue = queue

    def run(self):
        #
        while True:
            try:
                entry = self.parser.next()
                #
                self.queue.put(entry)
            except StopIteration:
                print('No more log, just sleep 5 seconds')
                time.sleep(1)



#!/usr/bin/env python3

import typer
import queue

#
from mysqlog.producer import SlowQueryLogProducer
from mysqlog.consumer import SlowQueryLogConsumer

#
app = typer.Typer()


@app.command()
def db(
    logpath: str,
    user: str = typer.Option(..., "-u", "--user"),
    password: str = typer.Option(..., "-p", "--password"),
    host: str = typer.Option("localhost", "-h", "--host"),
    database: str = typer.Option("test", "-d", "--database"),
):
    f = open(logpath)
    q = queue.Queue(100)

    producer = SlowQueryLogProducer(f, q)
    consumer = SlowQueryLogConsumer(q, host=host, user=user, password=password, database=database)

    producer.start()
    consumer.start()


if __name__ == "__main__":
    app()



import threading
import hashlib
import pymysql


class SlowQueryLogConsumer(threading.Thread):
    def __init__(self, queue, **config):
        threading.Thread.__init__(self, name="consumber")
        print(config)
        self.queue = queue
        self.connection = pymysql.connect(
            host=config["host"],
            user=config["user"],
            password=config["password"],
            database=config["database"],
            cursorclass=pymysql.cursors.DictCursor,
        )

    def run(self):
        #
        while True:
            with self.connection.cursor() as cursor:
                entry = self.queue.get()
                entry["md5"] = hashlib.md5(
                    f"{entry['datetime']}{entry['query']}{entry['query_time']}".encode("utf-8")
                ).hexdigest()
                #
                print(entry)
                #
                insert_sql = "INSERT IGNORE INTO `mysql_slow_query_log` (`md5`, `datetime`, `database`, `user`, `host`, `query`, `query_time`, `lock_time`, `rows_examined`, `rows_sent`) VALUES (%s, %s, %s, %s, %s, %s, %s, %s, %s, %s)"
                #
                cursor.execute(
                    insert_sql,
                    (
                        entry["md5"],
                        entry["datetime"],
                        entry["database"],
                        entry["user"],
                        entry["host"],
                        entry["query"],
                        entry["query_time"],
                        entry["lock_time"],
                        entry["rows_examined"],
                        entry["rows_sent"],
                    ),
                )
                #
                self.connection.commit()
